Welcome to pyGMM's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   readme
   installation
   usage
   models
   contributing
   authors
   history
   zreferences


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
